@@ -2,6 +2,7 @@ from .add_item import AddItem, AddItemByReference  # noqa: F401
 from .add_label import AddLabel  # noqa: F401
 from .add_metadata import AddMetadata  # noqa: F401
 from .add_range import AddRange  # noqa: F401
+from .add_service import AddService  # noqa: F401
 from .annotation_helpers import AnnotationHelpers  # noqa: F401
 from .auto_fields import *  # noqa: F401,F403
 from .canvas_helpers import AddImageToCanvas  # noqa: F401
@@ -11,6 +12,7 @@ from .make_canvas import MakeCanvas  # noqa: F401
 from .make_collection import MakeCollection  # noqa: F401
 from .make_manifest import MakeManifest  # noqa: F401
 from .make_range import MakeRange  # noqa: F401
+from .make_service import MakeService  # noqa: F401
 from .set_hwd import SetHwd  # noqa: F401
 from .set_hwd_from_file import SetHeightWidthDurationFileHelper  # noqa: F401
 from .set_hwd_from_iiif import SetHwdFromIIIF  # noqa: F401
